@@ -1545,7 +1545,7 @@ startup_cb (GApplication *application)
 
   settings = g_settings_new ("org.gnome.five-or-more");
 
-  highscores = games_scores_new ("glines",
+  highscores = games_scores_new ("five-or-more",
                                  scorecats, G_N_ELEMENTS (scorecats),
                                  "board size", NULL,
                                  0 /* default category */,
@@ -1618,11 +1618,10 @@ startup_cb (GApplication *application)
                     G_CALLBACK (configure_event_callback), NULL);
   g_signal_connect (draw_area, "draw",
                     G_CALLBACK (field_draw_callback), NULL);
-  gtk_widget_set_size_request (draw_area, 400, 400);
   gridframe = games_grid_frame_new (hfieldsize, vfieldsize);
   games_grid_frame_set_padding (GAMES_GRID_FRAME (gridframe), 1, 1);
   gtk_container_add (GTK_CONTAINER (gridframe), draw_area);
-  gtk_box_pack_start (GTK_BOX (hbox), gridframe, TRUE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), gridframe, TRUE, TRUE, 0);
 
   gtk_widget_set_events (draw_area,
                          gtk_widget_get_events (draw_area) |
@@ -1673,12 +1672,6 @@ main (int argc, char *argv[])
 
   rgen = g_rand_new ();
 
-  /* 
-   * Required for proper app menu because the binary doesn't match the desktop file.
-   * Has to be before the call to g_option_context_parse.
-   */
-  g_set_prgname ("glines");
-
   context = g_option_context_new (NULL);
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
